/*
* ==============================================================================
*  Name        : ShoutcastErrors.h
*  Part of     : Shoutcast Engine
*  Interface   :
*  Description : Defines the shoutcast engine error codes
*  Version     : 1
*
*  Copyright (c) 2006, Nokia Corporation All rights reserved. Redistribution
*  and use in source and binary forms, with or without modification, are
*  permitted provided that the following conditions are met: Redistributions
*  of source code must retain the above copyright notice, this list of
*  conditions and the following disclaimer. Redistributions in binary form
*  must reproduce the above copyright notice, this list of conditions and the
*  following disclaimer in the documentation and/or other materials provided
*  with the distribution. Neither the name of the Nokia Corporation nor the
*  names of its contributors may be used to endorse or promote products
*  derived from this software without specific prior written permission. THIS
*  SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
*  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
*  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
*  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
*  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
*  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
*  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
*  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
*  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*  POSSIBILITY OF SUCH DAMAGE.
* ==============================================================================
*/

#ifndef SHOUTCASTERRORS_H
#define SHOUTCASTERRORS_H

//This file contains Leave error codes and events returned by the Shoutcast controller
// 0x0100-0x01FF -> metadata changed (1 bit flags each metadata entity)

const TInt KShoutcastEvent_Connecting        =0x0201;
const TInt KShoutcastEvent_Reconnecting      =0x0202;
const TInt KShoutcastEvent_Connected         =0x0203;
const TInt KShoutcastEvent_Disconnected      =0x0204;
const TInt KShoutcastEvent_BufferEmpty       =0x0205;
const TInt KShoutcastEvent_BufferingComplete =0x0206;
//if it is less than 0, it is an error code!

const TInt KShoutcastMetaData_URL = 10;

//in Shoutcast Stream
const TInt KErrShoutcast_ReadFromFile=-1100; //Prime, file
const TInt KErrShoutcast_ConnectToSockServer=-1200;		//Connect2Server
const TInt KErrShoutcast_OpenSocket=-1300;				//Connect2Server
const TInt KErrShoutcast_Connecting2Server=-1400;		//Connect2Server
const TInt KErrShoutcast_SendingHTTPRequest=-1500;		//Connect2Server
const TInt KErrShoutcast_ReceivingHTTPResponse=-1600;	//Connect2Server
const TInt KErrShoutcast_NoHTTPServer=-1700;			//Connect2Server
const TInt KErrShoutcast_BadIcyMetadataFormat=-1800;	//Connect2Server
const TInt KErrShoutcast_NoShoutcastServer=-1900; 	    //...or the answer was not OK //Connect2Server
const TInt KErrShoutcast_FormatNotSupported=-2000;		//Stream format not supported

//Waiting messages
_LIT(KMsgShoutcast_Connecting,"Connecting to ");
_LIT(KMsgShoutcast_Reconnecting,"Reconnecting to ");

//Error messages. These should go into a .loc file
_LIT(KErrMsgShoutcast_Controller,"Error Opening SHOUTcast controller.");
_LIT(KErrMsgShoutcast_AddDataSink,"Error Opening Sound Device.");

_LIT(KErrMsgShoutcast_AddDataSource_PlaylistNotFound,"Error: SHOUTcast Playlist not found.");
_LIT(KErrMsgShoutcast_AddDataSource_URLNotFound,"Error: No SHOUTcast URLfound in Playlist.");

_LIT(KErrMsgShoutcast_Prime,"Error connecting to server.");
_LIT(KErrMsgShoutcast_Play,"Error playing.");


_LIT(KErrMsgShoutcast_ReadFromFile,"Could not read from mp3 file.");
_LIT(KErrMsgShoutcast_ConnectToSockServer,"Could not connect to socket server.");
_LIT(KErrMsgShoutcast_OpenSocket,"Could not open the socket.");
_LIT(KErrMsgShoutcast_Connecting2Server,"Could not connect to server.");
_LIT(KErrMsgShoutcast_SendingHTTPRequest,"Could not send SHOUTcast request.");
_LIT(KErrMsgShoutcast_ReceivingHTTPResponse,"Could not receive SHOUTcast response.");
_LIT(KErrMsgShoutcast_NoHTTPServer,"This server is not a HTTP/SHOUTcast Server.");
_LIT(KErrMsgShoutcast_BadIcyMetadataFormat,"Bad Icy Metadata format. Transmission looks corruptd.");
_LIT(KErrMsgShoutcast_NoShoutcastServer,"This server is not a SHOUTcast Server (or not OK answer received).");
_LIT(KErrMsgShoutcast_FormatNotSupported,"The stream format is not supported.");

#endif //SHOUTCASTERRORS_H

// End of File
